﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

// Open the Add Reference dialog and on the COM tab add a reference to 
// "Microsoft Word 14.0 Object Library" (or whatever version you have
// installed on your system). 
using Word = Microsoft.Office.Interop.Word;
using System.IO;

namespace howto_load_word_pictures
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // Load the directory setting.
        private void Form1_Load(object sender, EventArgs e)
        {
            clbFiles.Sorted = true;
            clbFiles.CheckOnClick = true;
            clbFiles.HorizontalScrollbar = true;
            txtDirectory.Text = Properties.Settings.Default.Directory;
            cboPattern.Text = Properties.Settings.Default.Patterns;
            txtFilename.Text = Properties.Settings.Default.WordFile;

            if (txtDirectory.Text.Length == 0)
                txtDirectory.Text = Application.StartupPath;
            if (cboPattern.Text.Length == 0) cboPattern.SelectedIndex = 0;
            if (txtFilename.Text.Length == 0)
                txtFilename.Text = Application.StartupPath + "\\Pictures.docx";
        }

        // Save the directory setting.
        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            Properties.Settings.Default.Directory = txtDirectory.Text;
            Properties.Settings.Default.Patterns = cboPattern.Text;
            Properties.Settings.Default.WordFile = txtFilename.Text;
            Properties.Settings.Default.Save();
        }

        // Let the user select a folder.
        private void btnBrowse_Click(object sender, EventArgs e)
        {
            fbdDirectory.SelectedPath = txtDirectory.Text;
            if (fbdDirectory.ShowDialog() == DialogResult.OK)
            {
                txtDirectory.Text = fbdDirectory.SelectedPath;
            }
        }

        // List files that match the pattern.
        private void btnListFiles_Click(object sender, EventArgs e)
        {
            // Get the directory.
            string path = txtDirectory.Text.Trim();
            if (path.Length == 0)
            {
                MessageBox.Show("Please enter a directory name");
                return;
            }

            // Get the file pattern text without parentheses.
            string pattern_text = cboPattern.Text;
            if (pattern_text.Contains("("))
            {
                int pos1 = pattern_text.IndexOf("(");
                int pos2 = pattern_text.IndexOf(")");
                pattern_text = pattern_text.Substring(pos1 + 1, pos2 - pos1 - 1);
            }

            // Get individual file matching patterns.
            List<string> patterns = new List<string>();
            foreach (string pattern in pattern_text.Split(
                new char[] { ';' }, StringSplitOptions.RemoveEmptyEntries))
            {
                patterns.Add(pattern.Trim());
            }

            // Get the files.
            SearchOption search_option = SearchOption.TopDirectoryOnly;
            if (chkIncludeSubdirectories.Checked)
                search_option = SearchOption.AllDirectories;
            clbFiles.Items.Clear();
            chkAll.Checked = false;
            foreach (string pattern in patterns)
            {
                // Get files matching this pattern.
                foreach (string filename in
                    Directory.GetFiles(path, pattern, search_option))
                {
                    // See if we not yet listed this file.
                    if (!clbFiles.Items.Contains(filename))
                    {
                        // Add the filename to the list.
                        clbFiles.Items.Add(filename);
                    }
                }
            }

            // Initially select all files.
            chkAll.Checked = true;
        }

        // Check or uncheck all of the files.
        private void chkAll_CheckedChanged(object sender, EventArgs e)
        {
            bool is_checked = chkAll.Checked;
            for (int i = 0; i < clbFiles.Items.Count; i++)
                clbFiles.SetItemChecked(i, is_checked);
        }

        // Create the Word document.
        private void btnCreateFile_Click(object sender, EventArgs e)
        {
            // Get the file name.
            string filename = txtFilename.Text.Trim();
            if (filename.Length == 0)
            {
                MessageBox.Show("Please enter a document name");
                return;
            }

            // Get the Word application object.
            Word._Application word_app = new Word.ApplicationClass();

            // Make Word visible (optional).
            word_app.Visible = true;

            // Create the Word document.
            object missing = Type.Missing;
            Word._Document word_doc = word_app.Documents.Add(
                ref missing, ref missing, ref missing, ref missing);

            // Add the image files.
            Word.Paragraph para;
            foreach (string picture_file in clbFiles.CheckedItems)
            {
                // Make a paragraph.
                para = word_doc.Paragraphs.Add(ref missing);

                // Add the picture to the paragraph.
                Word.InlineShape inline_shape = para.Range.InlineShapes.AddPicture(
                    picture_file, ref missing, ref missing, ref missing);

                // Format the picture.
                Word.Shape shape = inline_shape.ConvertToShape();

                // Scale uniformly by 50%.
                shape.LockAspectRatio = Microsoft.Office.Core.MsoTriState.msoTrue;
                shape.ScaleHeight(0.5f, Microsoft.Office.Core.MsoTriState.msoTrue,
                    Microsoft.Office.Core.MsoScaleFrom.msoScaleFromTopLeft);
                shape.WrapFormat.Type = Word.WdWrapType.wdWrapInline;

                // Add the file's name.
                para.Range.InsertParagraphAfter();
                para.Range.InsertAfter(picture_file);
            }

            // Save the document.
            object filename_obj = filename;
            word_doc.SaveAs(ref filename_obj, ref missing, ref missing, ref missing,
                ref missing, ref missing, ref missing, ref missing, ref missing,
                ref missing, ref missing, ref missing, ref missing, ref missing,
                ref missing, ref missing);

            // Close.
            object save_changes = false;
            word_doc.Close(ref save_changes, ref missing, ref missing);
            word_app.Quit(ref save_changes, ref missing, ref missing);

            MessageBox.Show("Done");
        }

        // Let the user sleect the Word document.
        private void btnSelectFile_Click(object sender, EventArgs e)
        {
            sfdWordDoc.FileName = txtFilename.Text;
            if (sfdWordDoc.ShowDialog() == DialogResult.OK)
            {
                txtFilename.Text = sfdWordDoc.FileName;
            }
        }
    }
}
